@@ -25,6 +25,7 @@ class View(MetricsLayerBase, SQLReplacement):
         "model_name",
         "label",
         "description",
+        "hidden",
         "sql_table_name",
         "derived_table",
         "default_date",
@@ -35,6 +36,7 @@ class View(MetricsLayerBase, SQLReplacement):
         "required_access_grants",
         "event_dimension",
         "event_name",
+        "extra",
         "identifiers",
         "fields",
         "fields_for_analysis",
@@ -60,6 +62,10 @@ class View(MetricsLayerBase, SQLReplacement):
             )
         return
 
+    @property
+    def hidden(self):
+        return self._definition.get("hidden", False)
+
     @property
     def identifiers(self):
         if "identifiers" in self._definition:
@@ -216,6 +222,17 @@ class View(MetricsLayerBase, SQLReplacement):
                 )
             )
 
+        if "hidden" in self._definition and not isinstance(self.hidden, bool):
+            errors.append(
+                self._error(
+                    self._definition["hidden"],
+                    (
+                        f"View {self.name} has an invalid hidden value of"
+                        f" {self.hidden}. hidden must be a boolean (true or false)."
+                    ),
+                )
+            )
+
         if "sql_table_name" in self._definition and "derived_table" in self._definition:
             errors.append(
                 self._error(
@@ -327,6 +344,14 @@ class View(MetricsLayerBase, SQLReplacement):
                 )
             )
 
+        if "extra" in self._definition and not isinstance(self.extra, dict):
+            errors.append(
+                self._error(
+                    self._definition["extra"],
+                    f"View {self.name} has an invalid extra {self.extra}. The extra must be a dictionary.",
+                )
+            )
+
         if "sets" in self._definition and not isinstance(self.sets, list):
             errors.append(
                 self._error(
