@@ -79,7 +79,9 @@ class MetricsLayerQuery(MetricsLayerQueryBase):
         # Parse any non-additive dimension on given metrics to collect
         # them as CTE's for the appropriate filters
         self.non_additive_ctes = []
-        for metric in definition.get("metrics", []):
+        metrics_in_select = definition.get("metrics", [])
+        metrics_in_having = [h.field.id() for h in self.having_filters if h.field]
+        for metric in metrics_in_select + metrics_in_having:
             metric_field = self.design.get_field(metric)
             for ref_field in [metric_field] + metric_field.referenced_fields(metric_field.sql):
                 if non_additive_dimension := ref_field.non_additive_dimension:
@@ -200,7 +202,7 @@ class MetricsLayerQuery(MetricsLayerQueryBase):
                 # When there are no group by dimensions, we need to join on a dummy join for the case filter
                 if len(group_by_dimensions) == 0:
                     join_sql = LiteralValueCriterion("1=1")
-                    base_query = base_query.join(Table(definition["cte_alias"])).on(join_sql)
+                    base_query = base_query.left_join(Table(definition["cte_alias"])).on(join_sql)
 
                 # When there are group by dimensions, we need to join on *all* those dimensions
                 else:
@@ -210,7 +212,7 @@ class MetricsLayerQuery(MetricsLayerQueryBase):
                         field_sql = self.get_sql(f)
                         condition.append(f"{field_sql}={definition['cte_alias']}.{f.alias(with_view=True)}")
                     join_sql = LiteralValueCriterion(" and ".join(condition))
-                    base_query = base_query.join(Table(definition["cte_alias"])).on(join_sql)
+                    base_query = base_query.left_join(Table(definition["cte_alias"])).on(join_sql)
 
         if self.funnel_filters:
             cte_alias = "link_filter_subquery"
